Welcome to ClientVPS Mirrors

Help for package rusk
Title: Beautiful Graphical Representation of Multiplication Tables on a Modular Circle
Version: 0.1.1
Description: By placing on a circle 10 points numbered from 1 to 10, and connecting them by a straight line to the point corresponding to its multiplication by 2. (1 must be connected to 1 * 2 = 2, point 2 must be set to 2 * 2 = 4, point 3 to 3 * 2 = 6 and so on). You will obtain an amazing geometric figure that complicates and beautifies itself by varying the number of points and the multiplication table you use.
License: GPL-3
URL: https://github.com/ThinkR-open/rusk
BugReports: https://github.com/ThinkR-open/rusk/issues
Depends: R (≥ 3.4.0)
Imports: dplyr, ggforce, ggplot2, reshape2, shiny, tidyr
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-05-27 09:08:47 UTC; Vincent
Author: Vincent Guyader [aut, cre]
Maintainer: Vincent Guyader <vincent@thinkr.fr>
Repository: CRAN
Date/Publication: 2018-05-27 13:55:45 UTC

Beautiful graphical representation of multiplication tables

Description

By placing on a circle 10 points numbered from 1 to 10, and connecting them by a straight line to the point corresponding to its multiplication by 2. (1 must be connected to 1 * 2 = 2, point 2 must be set to 2 * 2 = 4, point 3 to 3 * 2 = 6 and so on). You will obtain an amazing geometric figure that complicates and beautifies itself by varying the number of points and the multiplication table you use.

Details

Use draw() or draw_app()

Author(s)

vincent <vincent@thinkr.fr>

References

https://www.youtube.com/embed/qhbuKbxJsk8?rel=0

https://www.youtube.com/embed/-X49VQgi86E?rel=0


Beautiful graphical representation of multiplication tables

Description

By placing on a circle 10 points numbered from 1 to 10, and connecting them by a straight line to the point corresponding to its multiplication by 2. (1 must be connected to 1 * 2 = 2, point 2 must be set to 2 * 2 = 4, point 3 to 3 * 2 = 6 and so on). You will obtain an amazing geometric figure that complicates and beautifies itself by varying the number of points and the multiplication table you use.

Usage

draw(table = 2, modulo = 10, label = FALSE)

Arguments

table

muliplication table to plot

modulo

number of points to use

label

show number label

Value

a ggplot

Examples

draw(table=2,modulo = 10, label=TRUE)
draw(table=2,modulo = 50, label=FALSE)
draw(table=2,modulo = 250)
draw(table=10,modulo = 250)

open shiny app

Description

open shiny app

Usage

draw_app()

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.